@@ -21,15 +21,11 @@ func TestArchiveReaderSystemTar(t *testing.T) {
 	})
 	assert.NoError(t, err)
 
-	archiveReaderSystem, err := NewArchiveReaderSystem(
-		"archive.tar",
-		data,
-		ArchiveFormatTar,
-		ArchiveReaderSystemOptions{
-			RootAbsPath:     NewAbsPath("/home/user"),
-			StripComponents: 1,
-		},
-	)
+	options := ArchiveReaderSystemOptions{
+		RootAbsPath:     NewAbsPath("/home/user"),
+		StripComponents: 1,
+	}
+	archiveReaderSystem, err := NewArchiveReaderSystem("archive.tar", data, ArchiveFormatTar, options)
 	assert.NoError(t, err)
 
 	for _, tc := range []struct {
