@@ -3,13 +3,13 @@ package chezmoi
 import (
 	"fmt"
 	"io/fs"
+	"maps"
 	"runtime"
+	"slices"
 	"testing"
 
 	"github.com/alecthomas/assert/v2"
 	"github.com/muesli/combinator"
-
-	"github.com/twpayne/chezmoi/v2/internal/chezmoimaps"
 )
 
 func TestEntryStateEquivalent(t *testing.T) {
@@ -78,7 +78,7 @@ func TestEntryStateEquivalent(t *testing.T) {
 		"symlink_symlink_copy":  true,
 	}
 
-	entryStateKeys := chezmoimaps.SortedKeys(entryStates)
+	entryStateKeys := slices.Sorted(maps.Keys(entryStates))
 
 	testData := struct {
 		EntryState1Key []string
