@@ -16,7 +16,7 @@ func (i *Interpreter) ExecCommand(name string) *exec.Cmd {
 	if i.None() {
 		return exec.Command(name)
 	}
-	return exec.Command(i.Command, append(i.Args, name)...) //nolint:gosec
+	return exec.Command(i.Command, append(i.Args, name)...)
 }
 
 // None returns if i represents no interpreter.
