@@ -486,6 +486,18 @@ func (c *Config) toPrettyJsonTemplateFunc(args ...any) string { //nolint:revive,
 	return builder.String()
 }
 
+func (c *Config) toStringTemplateFunc(value any) string {
+	return anyToString(value)
+}
+
+func (c *Config) toStringsTemplateFunc(values ...any) []string {
+	result, err := anyToStringSlice(values)
+	if err != nil {
+		panic(err)
+	}
+	return result
+}
+
 func (c *Config) toTomlTemplateFunc(data any) string {
 	return string(mustValue(chezmoi.FormatTOML.Marshal(data)))
 }
@@ -504,20 +516,32 @@ func anyToString(value any) string {
 	case bool:
 		return strconv.FormatBool(value)
 	case *bool:
+		if value == nil {
+			return "false"
+		}
 		return strconv.FormatBool(*value)
 	case []byte:
 		return string(value)
 	case float64:
 		return strconv.FormatFloat(value, 'f', -1, 64)
 	case *float64:
+		if value == nil {
+			return "0"
+		}
 		return strconv.FormatFloat(*value, 'f', -1, 64)
 	case int:
 		return strconv.Itoa(value)
 	case *int:
+		if value == nil {
+			return "0"
+		}
 		return strconv.Itoa(*value)
 	case string:
 		return value
 	case *string:
+		if value == nil {
+			return ""
+		}
 		return *value
 	case error:
 		return value.Error()
@@ -536,6 +560,24 @@ func anyToStringSlice(slice any) ([]string, error) {
 			result[i] = anyToString(elem)
 		}
 		return result, nil
+	case []bool:
+		result := make([]string, len(slice))
+		for i, value := range slice {
+			result[i] = strconv.FormatBool(value)
+		}
+		return result, nil
+	case []float64:
+		result := make([]string, len(slice))
+		for i, value := range slice {
+			result[i] = strconv.FormatFloat(value, 'f', -1, 64)
+		}
+		return result, nil
+	case []int:
+		result := make([]string, len(slice))
+		for i, value := range slice {
+			result[i] = strconv.Itoa(value)
+		}
+		return result, nil
 	case []string:
 		return slice, nil
 	default:
